# Form implementation generated from reading ui file '/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/widgets/canvas.ui'
#
# Created by: PyQt6 UI code generator 6.4.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(218, 218)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        Form.setMinimumSize(QtCore.QSize(66, 66))
        Form.setStyleSheet("b")
        self.gridLayout = QtWidgets.QGridLayout(Form)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setSpacing(0)
        self.gridLayout.setObjectName("gridLayout")
        self.canvas_container = QtWidgets.QFrame(parent=Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.canvas_container.sizePolicy().hasHeightForWidth())
        self.canvas_container.setSizePolicy(sizePolicy)
        self.canvas_container.setMinimumSize(QtCore.QSize(200, 200))
        self.canvas_container.setStyleSheet("")
        self.canvas_container.setFrameShape(QtWidgets.QFrame.Shape.NoFrame)
        self.canvas_container.setFrameShadow(QtWidgets.QFrame.Shadow.Plain)
        self.canvas_container.setMidLineWidth(0)
        self.canvas_container.setObjectName("canvas_container")
        self.gridLayout.addWidget(self.canvas_container, 0, 0, 1, 1)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))



# Form implementation generated from reading ui file '/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/main_window_new.ui'
#
# Created by: PyQt6 UI code generator 6.4.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(1150, 990)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(MainWindow.sizePolicy().hasHeightForWidth())
        MainWindow.setSizePolicy(sizePolicy)
        MainWindow.setMinimumSize(QtCore.QSize(0, 0))
        self.centralwidget = QtWidgets.QWidget(parent=MainWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.centralwidget.sizePolicy().hasHeightForWidth())
        self.centralwidget.setSizePolicy(sizePolicy)
        self.centralwidget.setMinimumSize(QtCore.QSize(1000, 512))
        self.centralwidget.setLayoutDirection(QtCore.Qt.LayoutDirection.LeftToRight)
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout = QtWidgets.QGridLayout(self.centralwidget)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setSpacing(0)
        self.gridLayout.setObjectName("gridLayout")
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(parent=MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1150, 22))
        self.menubar.setObjectName("menubar")
        self.menuFile = QtWidgets.QMenu(parent=self.menubar)
        self.menuFile.setObjectName("menuFile")
        self.menuEdit = QtWidgets.QMenu(parent=self.menubar)
        self.menuEdit.setObjectName("menuEdit")
        self.menuFilters = QtWidgets.QMenu(parent=self.menubar)
        self.menuFilters.setObjectName("menuFilters")
        self.menuBlur = QtWidgets.QMenu(parent=self.menuFilters)
        self.menuBlur.setObjectName("menuBlur")
        self.menuAbout = QtWidgets.QMenu(parent=self.menubar)
        self.menuAbout.setTearOffEnabled(False)
        self.menuAbout.setObjectName("menuAbout")
        self.menuModel_merge = QtWidgets.QMenu(parent=self.menubar)
        self.menuModel_merge.setObjectName("menuModel_merge")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(parent=MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.actionNew = QtGui.QAction(parent=MainWindow)
        self.actionNew.setObjectName("actionNew")
        self.actionImport = QtGui.QAction(parent=MainWindow)
        self.actionImport.setObjectName("actionImport")
        self.actionExport = QtGui.QAction(parent=MainWindow)
        self.actionExport.setObjectName("actionExport")
        self.actionCopy = QtGui.QAction(parent=MainWindow)
        self.actionCopy.setObjectName("actionCopy")
        self.actionPaste = QtGui.QAction(parent=MainWindow)
        self.actionPaste.setObjectName("actionPaste")
        self.actionUndo = QtGui.QAction(parent=MainWindow)
        self.actionUndo.setObjectName("actionUndo")
        self.actionRedo = QtGui.QAction(parent=MainWindow)
        self.actionRedo.setObjectName("actionRedo")
        self.actionGrid = QtGui.QAction(parent=MainWindow)
        self.actionGrid.setObjectName("actionGrid")
        self.actionPreferences = QtGui.QAction(parent=MainWindow)
        self.actionPreferences.setObjectName("actionPreferences")
        self.actionCanvas_color = QtGui.QAction(parent=MainWindow)
        self.actionCanvas_color.setObjectName("actionCanvas_color")
        self.actionReset_Settings = QtGui.QAction(parent=MainWindow)
        self.actionReset_Settings.setObjectName("actionReset_Settings")
        self.actionResize_on_Paste = QtGui.QAction(parent=MainWindow)
        self.actionResize_on_Paste.setCheckable(True)
        self.actionResize_on_Paste.setObjectName("actionResize_on_Paste")
        self.actionMemory = QtGui.QAction(parent=MainWindow)
        self.actionMemory.setObjectName("actionMemory")
        self.actionAbout = QtGui.QAction(parent=MainWindow)
        self.actionAbout.setObjectName("actionAbout")
        self.actionCheck_for_updates = QtGui.QAction(parent=MainWindow)
        self.actionCheck_for_updates.setObjectName("actionCheck_for_updates")
        self.actionOpen = QtGui.QAction(parent=MainWindow)
        self.actionOpen.setObjectName("actionOpen")
        self.actionView = QtGui.QAction(parent=MainWindow)
        self.actionView.setObjectName("actionView")
        self.actionAdvanced = QtGui.QAction(parent=MainWindow)
        self.actionAdvanced.setObjectName("actionAdvanced")
        self.actionGaussian_Blur = QtGui.QAction(parent=MainWindow)
        self.actionGaussian_Blur.setEnabled(True)
        self.actionGaussian_Blur.setObjectName("actionGaussian_Blur")
        self.actionBox_Blur = QtGui.QAction(parent=MainWindow)
        self.actionBox_Blur.setObjectName("actionBox_Blur")
        self.actionUnsharp_Mask = QtGui.QAction(parent=MainWindow)
        self.actionUnsharp_Mask.setObjectName("actionUnsharp_Mask")
        self.actionPixel_Art = QtGui.QAction(parent=MainWindow)
        self.actionPixel_Art.setVisible(True)
        self.actionPixel_Art.setObjectName("actionPixel_Art")
        self.actionInvert = QtGui.QAction(parent=MainWindow)
        self.actionInvert.setObjectName("actionInvert")
        self.actionSaturation = QtGui.QAction(parent=MainWindow)
        self.actionSaturation.setVisible(True)
        self.actionSaturation.setObjectName("actionSaturation")
        self.actionColor_Balance = QtGui.QAction(parent=MainWindow)
        self.actionColor_Balance.setEnabled(True)
        self.actionColor_Balance.setVisible(True)
        self.actionColor_Balance.setObjectName("actionColor_Balance")
        self.actionSave = QtGui.QAction(parent=MainWindow)
        self.actionSave.setObjectName("actionSave")
        self.actionLoad = QtGui.QAction(parent=MainWindow)
        self.actionLoad.setObjectName("actionLoad")
        self.actionQuit = QtGui.QAction(parent=MainWindow)
        self.actionQuit.setObjectName("actionQuit")
        self.actionPixel_Art_2 = QtGui.QAction(parent=MainWindow)
        self.actionPixel_Art_2.setObjectName("actionPixel_Art_2")
        self.actionBug_report = QtGui.QAction(parent=MainWindow)
        self.actionBug_report.setObjectName("actionBug_report")
        self.actionReport_vulnerability = QtGui.QAction(parent=MainWindow)
        self.actionReport_vulnerability.setObjectName("actionReport_vulnerability")
        self.actionDiscord = QtGui.QAction(parent=MainWindow)
        self.actionDiscord.setObjectName("actionDiscord")
        self.actionExtensions = QtGui.QAction(parent=MainWindow)
        self.actionExtensions.setObjectName("actionExtensions")
        self.actionShow_image_preview = QtGui.QAction(parent=MainWindow)
        self.actionShow_image_preview.setCheckable(True)
        self.actionShow_image_preview.setObjectName("actionShow_image_preview")
        self.actionImage_to_new_layer = QtGui.QAction(parent=MainWindow)
        self.actionImage_to_new_layer.setCheckable(True)
        self.actionImage_to_new_layer.setObjectName("actionImage_to_new_layer")
        self.actionAuto_export_images = QtGui.QAction(parent=MainWindow)
        self.actionAuto_export_images.setCheckable(True)
        self.actionAuto_export_images.setObjectName("actionAuto_export_images")
        self.actionImage_export_settings = QtGui.QAction(parent=MainWindow)
        self.actionImage_export_settings.setObjectName("actionImage_export_settings")
        self.actionCheck_for_latest_version_on_startup = QtGui.QAction(parent=MainWindow)
        self.actionCheck_for_latest_version_on_startup.setCheckable(True)
        self.actionCheck_for_latest_version_on_startup.setObjectName("actionCheck_for_latest_version_on_startup")
        self.actionModel_Merger = QtGui.QAction(parent=MainWindow)
        self.actionModel_Merger.setObjectName("actionModel_Merger")
        self.actionSaturation_Filter = QtGui.QAction(parent=MainWindow)
        self.actionSaturation_Filter.setObjectName("actionSaturation_Filter")
        self.actionColor_Balance_2 = QtGui.QAction(parent=MainWindow)
        self.actionColor_Balance_2.setObjectName("actionColor_Balance_2")
        self.actionRGB_Noise = QtGui.QAction(parent=MainWindow)
        self.actionRGB_Noise.setObjectName("actionRGB_Noise")
        self.actionGaussian_Blur_2 = QtGui.QAction(parent=MainWindow)
        self.actionGaussian_Blur_2.setObjectName("actionGaussian_Blur_2")
        self.actionBox_Blur_2 = QtGui.QAction(parent=MainWindow)
        self.actionBox_Blur_2.setObjectName("actionBox_Blur_2")
        self.actionRotate_90_clockwise = QtGui.QAction(parent=MainWindow)
        self.actionRotate_90_clockwise.setObjectName("actionRotate_90_clockwise")
        self.actionRotate_90_counter_clockwise = QtGui.QAction(parent=MainWindow)
        self.actionRotate_90_counter_clockwise.setObjectName("actionRotate_90_counter_clockwise")
        self.actionSave_prompt = QtGui.QAction(parent=MainWindow)
        self.actionSave_prompt.setObjectName("actionSave_prompt")
        self.actionPrompt_Browser = QtGui.QAction(parent=MainWindow)
        self.actionPrompt_Browser.setObjectName("actionPrompt_Browser")
        self.actionShow_Active_Image_Area = QtGui.QAction(parent=MainWindow)
        self.actionShow_Active_Image_Area.setCheckable(True)
        self.actionShow_Active_Image_Area.setObjectName("actionShow_Active_Image_Area")
        self.actionImage_Interpolation = QtGui.QAction(parent=MainWindow)
        self.actionImage_Interpolation.setObjectName("actionImage_Interpolation")
        self.image_interpolation = QtGui.QAction(parent=MainWindow)
        self.image_interpolation.setObjectName("image_interpolation")
        self.actionFilm = QtGui.QAction(parent=MainWindow)
        self.actionFilm.setObjectName("actionFilm")
        self.actionDeterministic_generation = QtGui.QAction(parent=MainWindow)
        self.actionDeterministic_generation.setObjectName("actionDeterministic_generation")
        self.actionDark_mode = QtGui.QAction(parent=MainWindow)
        self.actionDark_mode.setCheckable(True)
        self.actionDark_mode.setObjectName("actionDark_mode")
        self.actionConsole_window = QtGui.QAction(parent=MainWindow)
        self.actionConsole_window.setObjectName("actionConsole_window")
        self.actionSettings = QtGui.QAction(parent=MainWindow)
        self.actionSettings.setObjectName("actionSettings")
        self.actionEasy_prompt = QtGui.QAction(parent=MainWindow)
        self.actionEasy_prompt.setObjectName("actionEasy_prompt")
        self.menuFile.addAction(self.actionNew)
        self.menuFile.addAction(self.actionLoad)
        self.menuFile.addAction(self.actionSave)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionSettings)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionExport)
        self.menuFile.addAction(self.actionImport)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionSave_prompt)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionQuit)
        self.menuEdit.addAction(self.actionCopy)
        self.menuEdit.addAction(self.actionPaste)
        self.menuEdit.addAction(self.actionUndo)
        self.menuEdit.addAction(self.actionRedo)
        self.menuEdit.addSeparator()
        self.menuEdit.addAction(self.actionRotate_90_clockwise)
        self.menuEdit.addAction(self.actionRotate_90_counter_clockwise)
        self.menuBlur.addSeparator()
        self.menuBlur.addAction(self.actionGaussian_Blur_2)
        self.menuBlur.addAction(self.actionBox_Blur_2)
        self.menuFilters.addAction(self.menuBlur.menuAction())
        self.menuFilters.addSeparator()
        self.menuFilters.addAction(self.actionColor_Balance)
        self.menuFilters.addAction(self.actionSaturation_Filter)
        self.menuFilters.addAction(self.actionUnsharp_Mask)
        self.menuFilters.addAction(self.actionRGB_Noise)
        self.menuFilters.addAction(self.actionPixel_Art)
        self.menuFilters.addSeparator()
        self.menuFilters.addAction(self.actionInvert)
        self.menuFilters.addAction(self.actionFilm)
        self.menuAbout.addAction(self.actionAbout)
        self.menuAbout.addAction(self.actionBug_report)
        self.menuAbout.addAction(self.actionReport_vulnerability)
        self.menuAbout.addAction(self.actionDiscord)
        self.menuModel_merge.addAction(self.image_interpolation)
        self.menuModel_merge.addSeparator()
        self.menuModel_merge.addAction(self.actionDeterministic_generation)
        self.menuModel_merge.addSeparator()
        self.menuModel_merge.addAction(self.actionModel_Merger)
        self.menuModel_merge.addSeparator()
        self.menuModel_merge.addAction(self.actionPrompt_Browser)
        self.menuModel_merge.addSeparator()
        self.menuModel_merge.addAction(self.actionEasy_prompt)
        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menuEdit.menuAction())
        self.menubar.addAction(self.menuModel_merge.menuAction())
        self.menubar.addAction(self.menuFilters.menuAction())
        self.menubar.addAction(self.menuAbout.menuAction())

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "AI Runner"))
        self.menuFile.setTitle(_translate("MainWindow", "File"))
        self.menuEdit.setTitle(_translate("MainWindow", "Edit"))
        self.menuFilters.setTitle(_translate("MainWindow", "Filters"))
        self.menuBlur.setTitle(_translate("MainWindow", "Blur"))
        self.menuAbout.setTitle(_translate("MainWindow", "Help"))
        self.menuModel_merge.setTitle(_translate("MainWindow", "Tools"))
        self.actionNew.setText(_translate("MainWindow", "New"))
        self.actionNew.setShortcut(_translate("MainWindow", "Ctrl+N"))
        self.actionImport.setText(_translate("MainWindow", "Import image"))
        self.actionImport.setShortcut(_translate("MainWindow", "Ctrl+I"))
        self.actionExport.setText(_translate("MainWindow", "Export image"))
        self.actionExport.setShortcut(_translate("MainWindow", "Ctrl+E"))
        self.actionCopy.setText(_translate("MainWindow", "Copy"))
        self.actionCopy.setShortcut(_translate("MainWindow", "Ctrl+C"))
        self.actionPaste.setText(_translate("MainWindow", "Paste"))
        self.actionPaste.setShortcut(_translate("MainWindow", "Ctrl+V"))
        self.actionUndo.setText(_translate("MainWindow", "Undo"))
        self.actionUndo.setShortcut(_translate("MainWindow", "Ctrl+Z"))
        self.actionRedo.setText(_translate("MainWindow", "Redo"))
        self.actionRedo.setShortcut(_translate("MainWindow", "Ctrl+Y"))
        self.actionGrid.setText(_translate("MainWindow", "Grid"))
        self.actionGrid.setToolTip(_translate("MainWindow", "Grid settings"))
        self.actionPreferences.setText(_translate("MainWindow", "Path Preferences"))
        self.actionPreferences.setToolTip(_translate("MainWindow", "Modify model path and more"))
        self.actionCanvas_color.setText(_translate("MainWindow", "Canvas color"))
        self.actionCanvas_color.setToolTip(_translate("MainWindow", "Change the color of the canvas"))
        self.actionReset_Settings.setText(_translate("MainWindow", "Reset Settings to Default"))
        self.actionReset_Settings.setToolTip(_translate("MainWindow", "Reset all settings to default"))
        self.actionResize_on_Paste.setText(_translate("MainWindow", "Resize on Import"))
        self.actionResize_on_Paste.setToolTip(_translate("MainWindow", "Resize the image to active grid area when importing"))
        self.actionMemory.setText(_translate("MainWindow", "Memory"))
        self.actionAbout.setText(_translate("MainWindow", "About"))
        self.actionCheck_for_updates.setText(_translate("MainWindow", "Check for updates"))
        self.actionOpen.setText(_translate("MainWindow", "Open"))
        self.actionView.setText(_translate("MainWindow", "View"))
        self.actionAdvanced.setText(_translate("MainWindow", "Memory Preferences"))
        self.actionAdvanced.setToolTip(_translate("MainWindow", "Change memory settings"))
        self.actionGaussian_Blur.setText(_translate("MainWindow", "Gaussian Blur"))
        self.actionBox_Blur.setText(_translate("MainWindow", "Box Blur"))
        self.actionUnsharp_Mask.setText(_translate("MainWindow", "Unsharp Mask"))
        self.actionPixel_Art.setText(_translate("MainWindow", "Pixel Art"))
        self.actionInvert.setText(_translate("MainWindow", "Invert"))
        self.actionSaturation.setText(_translate("MainWindow", "Saturation"))
        self.actionColor_Balance.setText(_translate("MainWindow", "Color Balance"))
        self.actionSave.setText(_translate("MainWindow", "Save"))
        self.actionSave.setShortcut(_translate("MainWindow", "Ctrl+S"))
        self.actionLoad.setText(_translate("MainWindow", "Open"))
        self.actionLoad.setShortcut(_translate("MainWindow", "Ctrl+O"))
        self.actionQuit.setText(_translate("MainWindow", "Quit"))
        self.actionQuit.setShortcut(_translate("MainWindow", "Ctrl+Q"))
        self.actionPixel_Art_2.setText(_translate("MainWindow", "Pixel Art"))
        self.actionBug_report.setText(_translate("MainWindow", "Bug report"))
        self.actionReport_vulnerability.setText(_translate("MainWindow", "Report vulnerability"))
        self.actionDiscord.setText(_translate("MainWindow", "Discord"))
        self.actionExtensions.setText(_translate("MainWindow", "Extensions"))
        self.actionExtensions.setToolTip(_translate("MainWindow", "Install, update and delete extensions"))
        self.actionShow_image_preview.setText(_translate("MainWindow", "Show image preview"))
        self.actionImage_to_new_layer.setText(_translate("MainWindow", "Image to new layer"))
        self.actionImage_to_new_layer.setToolTip(_translate("MainWindow", "Send generated images to new layer"))
        self.actionAuto_export_images.setText(_translate("MainWindow", "Auto export images"))
        self.actionAuto_export_images.setToolTip(_translate("MainWindow", "Automatically export newly generated images to a folder"))
        self.actionImage_export_settings.setText(_translate("MainWindow", "Import / export preferences"))
        self.actionCheck_for_latest_version_on_startup.setText(_translate("MainWindow", "Check for latest version on startup"))
        self.actionModel_Merger.setText(_translate("MainWindow", "Model Merger"))
        self.actionSaturation_Filter.setText(_translate("MainWindow", "Saturation"))
        self.actionColor_Balance_2.setText(_translate("MainWindow", "Color Balance"))
        self.actionRGB_Noise.setText(_translate("MainWindow", "RGB Noise"))
        self.actionGaussian_Blur_2.setText(_translate("MainWindow", "Gaussian Blur"))
        self.actionBox_Blur_2.setText(_translate("MainWindow", "Box Blur"))
        self.actionRotate_90_clockwise.setText(_translate("MainWindow", "Rotate 90° clockwise"))
        self.actionRotate_90_clockwise.setShortcut(_translate("MainWindow", "Ctrl+R"))
        self.actionRotate_90_counter_clockwise.setText(_translate("MainWindow", "Rotate 90° counter clockwise"))
        self.actionRotate_90_counter_clockwise.setShortcut(_translate("MainWindow", "Ctrl+Shift+R"))
        self.actionSave_prompt.setText(_translate("MainWindow", "Save prompt"))
        self.actionPrompt_Browser.setText(_translate("MainWindow", "Prompt Browser"))
        self.actionShow_Active_Image_Area.setText(_translate("MainWindow", "Show Active Image Area"))
        self.actionImage_Interpolation.setText(_translate("MainWindow", "Image Interpolation"))
        self.image_interpolation.setText(_translate("MainWindow", "Image Interpolation"))
        self.actionFilm.setText(_translate("MainWindow", "Film"))
        self.actionDeterministic_generation.setText(_translate("MainWindow", "Deterministic generator"))
        self.actionDark_mode.setText(_translate("MainWindow", "Dark mode"))
        self.actionConsole_window.setText(_translate("MainWindow", "Console window"))
        self.actionSettings.setText(_translate("MainWindow", "Settings"))
        self.actionEasy_prompt.setText(_translate("MainWindow", "Easy prompt"))



# Form implementation generated from reading ui file '/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/generate_form.ui'
#
# Created by: PyQt6 UI code generator 6.4.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(432, 1064)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        Form.setMinimumSize(QtCore.QSize(100, 0))
        Form.setLayoutDirection(QtCore.Qt.LayoutDirection.LeftToRight)
        self.gridLayout_7 = QtWidgets.QGridLayout(Form)
        self.gridLayout_7.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_7.setObjectName("gridLayout_7")
        self.scrollArea = QtWidgets.QScrollArea(parent=Form)
        self.scrollArea.setFrameShape(QtWidgets.QFrame.Shape.NoFrame)
        self.scrollArea.setFrameShadow(QtWidgets.QFrame.Shadow.Plain)
        self.scrollArea.setLineWidth(0)
        self.scrollArea.setWidgetResizable(True)
        self.scrollArea.setObjectName("scrollArea")
        self.scrollAreaWidgetContents_3 = QtWidgets.QWidget()
        self.scrollAreaWidgetContents_3.setGeometry(QtCore.QRect(0, 0, 432, 1064))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.scrollAreaWidgetContents_3.sizePolicy().hasHeightForWidth())
        self.scrollAreaWidgetContents_3.setSizePolicy(sizePolicy)
        self.scrollAreaWidgetContents_3.setObjectName("scrollAreaWidgetContents_3")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.scrollAreaWidgetContents_3)
        self.gridLayout_4.setContentsMargins(5, 0, 5, 0)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.gridLayout_2 = QtWidgets.QGridLayout()
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.label = QtWidgets.QLabel(parent=self.scrollAreaWidgetContents_3)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.gridLayout_2.addWidget(self.label, 7, 0, 1, 1)
        self.controlnet_groupbox = QtWidgets.QGroupBox(parent=self.scrollAreaWidgetContents_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.controlnet_groupbox.sizePolicy().hasHeightForWidth())
        self.controlnet_groupbox.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        self.controlnet_groupbox.setFont(font)
        self.controlnet_groupbox.setObjectName("controlnet_groupbox")
        self.gridLayout_5 = QtWidgets.QGridLayout(self.controlnet_groupbox)
        self.gridLayout_5.setContentsMargins(-1, 6, 6, 6)
        self.gridLayout_5.setObjectName("gridLayout_5")
        self.controlnet_guidance_scale_slider = QtWidgets.QSlider(parent=self.controlnet_groupbox)
        self.controlnet_guidance_scale_slider.setMaximum(100)
        self.controlnet_guidance_scale_slider.setPageStep(1)
        self.controlnet_guidance_scale_slider.setProperty("value", 50)
        self.controlnet_guidance_scale_slider.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.controlnet_guidance_scale_slider.setObjectName("controlnet_guidance_scale_slider")
        self.gridLayout_5.addWidget(self.controlnet_guidance_scale_slider, 0, 0, 1, 1)
        self.controlnet_guidance_scale_spinbox = QtWidgets.QDoubleSpinBox(parent=self.controlnet_groupbox)
        self.controlnet_guidance_scale_spinbox.setMinimumSize(QtCore.QSize(75, 24))
        self.controlnet_guidance_scale_spinbox.setMaximumSize(QtCore.QSize(75, 16777215))
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(False)
        self.controlnet_guidance_scale_spinbox.setFont(font)
        self.controlnet_guidance_scale_spinbox.setMaximum(1.0)
        self.controlnet_guidance_scale_spinbox.setSingleStep(0.01)
        self.controlnet_guidance_scale_spinbox.setProperty("value", 0.5)
        self.controlnet_guidance_scale_spinbox.setObjectName("controlnet_guidance_scale_spinbox")
        self.gridLayout_5.addWidget(self.controlnet_guidance_scale_spinbox, 0, 1, 1, 1)
        self.gridLayout_2.addWidget(self.controlnet_groupbox, 14, 0, 1, 1)
        self.formLayout_6 = QtWidgets.QFormLayout()
        self.formLayout_6.setObjectName("formLayout_6")
        self.to_canvas_radio = QtWidgets.QRadioButton(parent=self.scrollAreaWidgetContents_3)
        font = QtGui.QFont()
        font.setPointSize(9)
        self.to_canvas_radio.setFont(font)
        self.to_canvas_radio.setChecked(True)
        self.to_canvas_radio.setObjectName("to_canvas_radio")
        self.formLayout_6.setWidget(0, QtWidgets.QFormLayout.ItemRole.LabelRole, self.to_canvas_radio)
        self.deterministic_radio = QtWidgets.QRadioButton(parent=self.scrollAreaWidgetContents_3)
        font = QtGui.QFont()
        font.setPointSize(9)
        self.deterministic_radio.setFont(font)
        self.deterministic_radio.setObjectName("deterministic_radio")
        self.formLayout_6.setWidget(0, QtWidgets.QFormLayout.ItemRole.FieldRole, self.deterministic_radio)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setSpacing(6)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.generate = QtWidgets.QPushButton(parent=self.scrollAreaWidgetContents_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.generate.sizePolicy().hasHeightForWidth())
        self.generate.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(9)
        self.generate.setFont(font)
        self.generate.setObjectName("generate")
        self.horizontalLayout_3.addWidget(self.generate)
        self.progressBar = QtWidgets.QProgressBar(parent=self.scrollAreaWidgetContents_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.progressBar.sizePolicy().hasHeightForWidth())
        self.progressBar.setSizePolicy(sizePolicy)
        self.progressBar.setMaximumSize(QtCore.QSize(16777215, 25))
        font = QtGui.QFont()
        font.setPointSize(9)
        self.progressBar.setFont(font)
        self.progressBar.setProperty("value", 0)
        self.progressBar.setObjectName("progressBar")
        self.horizontalLayout_3.addWidget(self.progressBar)
        self.formLayout_6.setLayout(1, QtWidgets.QFormLayout.ItemRole.SpanningRole, self.horizontalLayout_3)
        self.gridLayout_2.addLayout(self.formLayout_6, 26, 0, 1, 1)
        self.samples_groupbox = QtWidgets.QGroupBox(parent=self.scrollAreaWidgetContents_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.samples_groupbox.sizePolicy().hasHeightForWidth())
        self.samples_groupbox.setSizePolicy(sizePolicy)
        self.samples_groupbox.setMinimumSize(QtCore.QSize(0, 60))
        self.samples_groupbox.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        self.samples_groupbox.setFont(font)
        self.samples_groupbox.setObjectName("samples_groupbox")
        self.gridLayout_11 = QtWidgets.QGridLayout(self.samples_groupbox)
        self.gridLayout_11.setContentsMargins(9, 6, 6, 6)
        self.gridLayout_11.setObjectName("gridLayout_11")
        self.samples_slider = QtWidgets.QSlider(parent=self.samples_groupbox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.samples_slider.sizePolicy().hasHeightForWidth())
        self.samples_slider.setSizePolicy(sizePolicy)
        self.samples_slider.setMinimumSize(QtCore.QSize(50, 0))
        self.samples_slider.setMinimum(1)
        self.samples_slider.setMaximum(200)
        self.samples_slider.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.samples_slider.setObjectName("samples_slider")
        self.gridLayout_11.addWidget(self.samples_slider, 0, 0, 1, 1)
        self.samples_spinbox = QtWidgets.QSpinBox(parent=self.samples_groupbox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.samples_spinbox.sizePolicy().hasHeightForWidth())
        self.samples_spinbox.setSizePolicy(sizePolicy)
        self.samples_spinbox.setMinimumSize(QtCore.QSize(0, 24))
        self.samples_spinbox.setMaximumSize(QtCore.QSize(16777215, 24))
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        self.samples_spinbox.setFont(font)
        self.samples_spinbox.setMinimum(1)
        self.samples_spinbox.setMaximum(200)
        self.samples_spinbox.setObjectName("samples_spinbox")
        self.gridLayout_11.addWidget(self.samples_spinbox, 0, 1, 1, 1)
        self.interrupt_button = QtWidgets.QPushButton(parent=self.samples_groupbox)
        self.interrupt_button.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.interrupt_button.sizePolicy().hasHeightForWidth())
        self.interrupt_button.setSizePolicy(sizePolicy)
        self.interrupt_button.setMinimumSize(QtCore.QSize(0, 24))
        self.interrupt_button.setMaximumSize(QtCore.QSize(16777215, 24))
        self.interrupt_button.setObjectName("interrupt_button")
        self.gridLayout_11.addWidget(self.interrupt_button, 0, 2, 1, 1)
        self.gridLayout_2.addWidget(self.samples_groupbox, 22, 0, 1, 1)
        self.scheduler_dropdown = QtWidgets.QComboBox(parent=self.scrollAreaWidgetContents_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.scheduler_dropdown.sizePolicy().hasHeightForWidth())
        self.scheduler_dropdown.setSizePolicy(sizePolicy)
        self.scheduler_dropdown.setMinimumSize(QtCore.QSize(50, 0))
        self.scheduler_dropdown.setMaximumSize(QtCore.QSize(16777215, 25))
        font = QtGui.QFont()
        font.setPointSize(9)
        self.scheduler_dropdown.setFont(font)
        self.scheduler_dropdown.setObjectName("scheduler_dropdown")
        self.gridLayout_2.addWidget(self.scheduler_dropdown, 10, 0, 1, 1)
        self.strength = QtWidgets.QGroupBox(parent=self.scrollAreaWidgetContents_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.strength.sizePolicy().hasHeightForWidth())
        self.strength.setSizePolicy(sizePolicy)
        self.strength.setMinimumSize(QtCore.QSize(0, 60))
        self.strength.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        self.strength.setFont(font)
        self.strength.setObjectName("strength")
        self.gridLayout_10 = QtWidgets.QGridLayout(self.strength)
        self.gridLayout_10.setContentsMargins(9, 6, 6, 6)
        self.gridLayout_10.setObjectName("gridLayout_10")
        self.strength_slider = QtWidgets.QSlider(parent=self.strength)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.strength_slider.sizePolicy().hasHeightForWidth())
        self.strength_slider.setSizePolicy(sizePolicy)
        self.strength_slider.setMinimumSize(QtCore.QSize(50, 0))
        self.strength_slider.setMaximum(100)
        self.strength_slider.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.strength_slider.setObjectName("strength_slider")
        self.gridLayout_10.addWidget(self.strength_slider, 0, 0, 1, 1)
        self.strength_spinbox = QtWidgets.QDoubleSpinBox(parent=self.strength)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Maximum, QtWidgets.QSizePolicy.Policy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.strength_spinbox.sizePolicy().hasHeightForWidth())
        self.strength_spinbox.setSizePolicy(sizePolicy)
        self.strength_spinbox.setMinimumSize(QtCore.QSize(75, 24))
        self.strength_spinbox.setMaximumSize(QtCore.QSize(75, 24))
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(False)
        self.strength_spinbox.setFont(font)
        self.strength_spinbox.setAlignment(QtCore.Qt.AlignmentFlag.AlignLeading|QtCore.Qt.AlignmentFlag.AlignLeft|QtCore.Qt.AlignmentFlag.AlignVCenter)
        self.strength_spinbox.setMaximum(100.0)
        self.strength_spinbox.setSingleStep(0.01)
        self.strength_spinbox.setObjectName("strength_spinbox")
        self.gridLayout_10.addWidget(self.strength_spinbox, 0, 1, 1, 1)
        self.gridLayout_2.addWidget(self.strength, 20, 0, 1, 1)
        self.prompt = QtWidgets.QPlainTextEdit(parent=self.scrollAreaWidgetContents_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.prompt.sizePolicy().hasHeightForWidth())
        self.prompt.setSizePolicy(sizePolicy)
        self.prompt.setMinimumSize(QtCore.QSize(50, 75))
        self.prompt.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.prompt.setFont(font)
        self.prompt.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.prompt.setObjectName("prompt")
        self.gridLayout_2.addWidget(self.prompt, 3, 0, 1, 1)
        self.downscale_settings = QtWidgets.QGridLayout()
        self.downscale_settings.setObjectName("downscale_settings")
        self.downscale_settings_sizes = QtWidgets.QVBoxLayout()
        self.downscale_settings_sizes.setObjectName("downscale_settings_sizes")
        self.downscale_settings_radiobuttons = QtWidgets.QVBoxLayout()
        self.downscale_settings_radiobuttons.setObjectName("downscale_settings_radiobuttons")
        self.full_image_radiobutton = QtWidgets.QRadioButton(parent=self.scrollAreaWidgetContents_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.full_image_radiobutton.sizePolicy().hasHeightForWidth())
        self.full_image_radiobutton.setSizePolicy(sizePolicy)
        self.full_image_radiobutton.setMinimumSize(QtCore.QSize(75, 0))
        font = QtGui.QFont()
        font.setPointSize(9)
        self.full_image_radiobutton.setFont(font)
        self.full_image_radiobutton.setObjectName("full_image_radiobutton")
        self.downscale_settings_radiobuttons.addWidget(self.full_image_radiobutton)
        self.active_grid_radiobutton = QtWidgets.QRadioButton(parent=self.scrollAreaWidgetContents_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.active_grid_radiobutton.sizePolicy().hasHeightForWidth())
        self.active_grid_radiobutton.setSizePolicy(sizePolicy)
        self.active_grid_radiobutton.setMinimumSize(QtCore.QSize(75, 0))
        font = QtGui.QFont()
        font.setPointSize(9)
        self.active_grid_radiobutton.setFont(font)
        self.active_grid_radiobutton.setObjectName("active_grid_radiobutton")
        self.downscale_settings_radiobuttons.addWidget(self.active_grid_radiobutton)
        self.downscale_settings_sizes.addLayout(self.downscale_settings_radiobuttons)
        self.downscale_label = QtWidgets.QLabel(parent=self.scrollAreaWidgetContents_3)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        self.downscale_label.setFont(font)
        self.downscale_label.setObjectName("downscale_label")
        self.downscale_settings_sizes.addWidget(self.downscale_label)
        self.downscale_amount_container = QtWidgets.QHBoxLayout()
        self.downscale_amount_container.setObjectName("downscale_amount_container")
        self.downscale_spinbox = QtWidgets.QSpinBox(parent=self.scrollAreaWidgetContents_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Maximum, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.downscale_spinbox.sizePolicy().hasHeightForWidth())
        self.downscale_spinbox.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(9)
        self.downscale_spinbox.setFont(font)
        self.downscale_spinbox.setMaximum(12)
        self.downscale_spinbox.setObjectName("downscale_spinbox")
        self.downscale_amount_container.addWidget(self.downscale_spinbox)
        self.final_size_label = QtWidgets.QLabel(parent=self.scrollAreaWidgetContents_3)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(False)
        self.final_size_label.setFont(font)
        self.final_size_label.setObjectName("final_size_label")
        self.downscale_amount_container.addWidget(self.final_size_label)
        self.final_size = QtWidgets.QLabel(parent=self.scrollAreaWidgetContents_3)
        font = QtGui.QFont()
        font.setPointSize(9)
        self.final_size.setFont(font)
        self.final_size.setObjectName("final_size")
        self.downscale_amount_container.addWidget(self.final_size)
        self.downscale_settings_sizes.addLayout(self.downscale_amount_container)
        self.downscale_settings.addLayout(self.downscale_settings_sizes, 0, 0, 1, 1)
        self.gridLayout_2.addLayout(self.downscale_settings, 25, 0, 1, 1)
        self.groupBox_24 = QtWidgets.QGroupBox(parent=self.scrollAreaWidgetContents_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_24.sizePolicy().hasHeightForWidth())
        self.groupBox_24.setSizePolicy(sizePolicy)
        self.groupBox_24.setMinimumSize(QtCore.QSize(75, 60))
        self.groupBox_24.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        self.groupBox_24.setFont(font)
        self.groupBox_24.setObjectName("groupBox_24")
        self.gridLayout_12 = QtWidgets.QGridLayout(self.groupBox_24)
        self.gridLayout_12.setContentsMargins(9, 9, 9, 9)
        self.gridLayout_12.setObjectName("gridLayout_12")
        self.seed = QtWidgets.QTextEdit(parent=self.groupBox_24)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.seed.sizePolicy().hasHeightForWidth())
        self.seed.setSizePolicy(sizePolicy)
        self.seed.setMinimumSize(QtCore.QSize(50, 24))
        self.seed.setMaximumSize(QtCore.QSize(16777215, 24))
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        self.seed.setFont(font)
        self.seed.setObjectName("seed")
        self.gridLayout_12.addWidget(self.seed, 0, 0, 1, 1)
        self.random_checkbox = QtWidgets.QCheckBox(parent=self.groupBox_24)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.random_checkbox.sizePolicy().hasHeightForWidth())
        self.random_checkbox.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        self.random_checkbox.setFont(font)
        self.random_checkbox.setObjectName("random_checkbox")
        self.gridLayout_12.addWidget(self.random_checkbox, 0, 1, 1, 1)
        self.gridLayout_2.addWidget(self.groupBox_24, 21, 0, 1, 1)
        self.scheduler_label = QtWidgets.QLabel(parent=self.scrollAreaWidgetContents_3)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        self.scheduler_label.setFont(font)
        self.scheduler_label.setObjectName("scheduler_label")
        self.gridLayout_2.addWidget(self.scheduler_label, 9, 0, 1, 1)
        self.groupBox_21 = QtWidgets.QGroupBox(parent=self.scrollAreaWidgetContents_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_21.sizePolicy().hasHeightForWidth())
        self.groupBox_21.setSizePolicy(sizePolicy)
        self.groupBox_21.setMinimumSize(QtCore.QSize(75, 60))
        self.groupBox_21.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        self.groupBox_21.setFont(font)
        self.groupBox_21.setAlignment(QtCore.Qt.AlignmentFlag.AlignLeading|QtCore.Qt.AlignmentFlag.AlignLeft|QtCore.Qt.AlignmentFlag.AlignVCenter)
        self.groupBox_21.setObjectName("groupBox_21")
        self.gridLayout_6 = QtWidgets.QGridLayout(self.groupBox_21)
        self.gridLayout_6.setContentsMargins(9, 6, 6, 6)
        self.gridLayout_6.setObjectName("gridLayout_6")
        self.steps_slider = QtWidgets.QSlider(parent=self.groupBox_21)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.steps_slider.sizePolicy().hasHeightForWidth())
        self.steps_slider.setSizePolicy(sizePolicy)
        self.steps_slider.setMinimumSize(QtCore.QSize(50, 0))
        self.steps_slider.setMinimum(1)
        self.steps_slider.setMaximum(200)
        self.steps_slider.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.steps_slider.setObjectName("steps_slider")
        self.gridLayout_6.addWidget(self.steps_slider, 0, 0, 1, 1)
        self.steps_spinbox = QtWidgets.QSpinBox(parent=self.groupBox_21)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.steps_spinbox.sizePolicy().hasHeightForWidth())
        self.steps_spinbox.setSizePolicy(sizePolicy)
        self.steps_spinbox.setMinimumSize(QtCore.QSize(75, 24))
        self.steps_spinbox.setMaximumSize(QtCore.QSize(75, 24))
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(False)
        self.steps_spinbox.setFont(font)
        self.steps_spinbox.setMinimum(1)
        self.steps_spinbox.setMaximum(200)
        self.steps_spinbox.setObjectName("steps_spinbox")
        self.gridLayout_6.addWidget(self.steps_spinbox, 0, 1, 1, 1)
        self.gridLayout_2.addWidget(self.groupBox_21, 15, 0, 1, 1)
        self.scale_box = QtWidgets.QGroupBox(parent=self.scrollAreaWidgetContents_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.scale_box.sizePolicy().hasHeightForWidth())
        self.scale_box.setSizePolicy(sizePolicy)
        self.scale_box.setMinimumSize(QtCore.QSize(0, 60))
        self.scale_box.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        self.scale_box.setFont(font)
        self.scale_box.setFlat(False)
        self.scale_box.setCheckable(False)
        self.scale_box.setObjectName("scale_box")
        self.gridLayout_8 = QtWidgets.QGridLayout(self.scale_box)
        self.gridLayout_8.setContentsMargins(9, 6, 6, 6)
        self.gridLayout_8.setObjectName("gridLayout_8")
        self.scale_slider = QtWidgets.QSlider(parent=self.scale_box)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.scale_slider.sizePolicy().hasHeightForWidth())
        self.scale_slider.setSizePolicy(sizePolicy)
        self.scale_slider.setMinimumSize(QtCore.QSize(50, 0))
        self.scale_slider.setMaximum(10000)
        self.scale_slider.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.scale_slider.setObjectName("scale_slider")
        self.gridLayout_8.addWidget(self.scale_slider, 0, 0, 1, 1)
        self.scale_spinbox = QtWidgets.QDoubleSpinBox(parent=self.scale_box)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Maximum, QtWidgets.QSizePolicy.Policy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.scale_spinbox.sizePolicy().hasHeightForWidth())
        self.scale_spinbox.setSizePolicy(sizePolicy)
        self.scale_spinbox.setMinimumSize(QtCore.QSize(75, 24))
        self.scale_spinbox.setMaximumSize(QtCore.QSize(75, 24))
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(False)
        self.scale_spinbox.setFont(font)
        self.scale_spinbox.setMaximum(100.0)
        self.scale_spinbox.setSingleStep(0.01)
        self.scale_spinbox.setObjectName("scale_spinbox")
        self.gridLayout_8.addWidget(self.scale_spinbox, 0, 1, 1, 1)
        self.gridLayout_2.addWidget(self.scale_box, 18, 0, 1, 1)
        self.negative_prompt = QtWidgets.QPlainTextEdit(parent=self.scrollAreaWidgetContents_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.negative_prompt.sizePolicy().hasHeightForWidth())
        self.negative_prompt.setSizePolicy(sizePolicy)
        self.negative_prompt.setMinimumSize(QtCore.QSize(50, 75))
        self.negative_prompt.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.negative_prompt.setFont(font)
        self.negative_prompt.setObjectName("negative_prompt")
        self.gridLayout_2.addWidget(self.negative_prompt, 5, 0, 1, 1)
        self.model_dropdown = QtWidgets.QComboBox(parent=self.scrollAreaWidgetContents_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.model_dropdown.sizePolicy().hasHeightForWidth())
        self.model_dropdown.setSizePolicy(sizePolicy)
        self.model_dropdown.setMinimumSize(QtCore.QSize(50, 0))
        self.model_dropdown.setMaximumSize(QtCore.QSize(16777215, 25))
        font = QtGui.QFont()
        font.setPointSize(9)
        self.model_dropdown.setFont(font)
        self.model_dropdown.setObjectName("model_dropdown")
        self.gridLayout_2.addWidget(self.model_dropdown, 8, 0, 1, 1)
        self.label_5 = QtWidgets.QLabel(parent=self.scrollAreaWidgetContents_3)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        self.label_5.setFont(font)
        self.label_5.setObjectName("label_5")
        self.gridLayout_2.addWidget(self.label_5, 4, 0, 1, 1)
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.controlnet_label = QtWidgets.QLabel(parent=self.scrollAreaWidgetContents_3)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        self.controlnet_label.setFont(font)
        self.controlnet_label.setObjectName("controlnet_label")
        self.horizontalLayout_9.addWidget(self.controlnet_label)
        self.enable_controlnet_checkbox = QtWidgets.QCheckBox(parent=self.scrollAreaWidgetContents_3)
        font = QtGui.QFont()
        font.setPointSize(8)
        font.setBold(True)
        self.enable_controlnet_checkbox.setFont(font)
        self.enable_controlnet_checkbox.setLayoutDirection(QtCore.Qt.LayoutDirection.LeftToRight)
        self.enable_controlnet_checkbox.setObjectName("enable_controlnet_checkbox")
        self.horizontalLayout_9.addWidget(self.enable_controlnet_checkbox, 0, QtCore.Qt.AlignmentFlag.AlignRight)
        self.gridLayout_2.addLayout(self.horizontalLayout_9, 11, 0, 1, 1)
        self.controlnet_dropdown = QtWidgets.QComboBox(parent=self.scrollAreaWidgetContents_3)
        self.controlnet_dropdown.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.controlnet_dropdown.sizePolicy().hasHeightForWidth())
        self.controlnet_dropdown.setSizePolicy(sizePolicy)
        self.controlnet_dropdown.setMinimumSize(QtCore.QSize(50, 0))
        font = QtGui.QFont()
        font.setPointSize(9)
        self.controlnet_dropdown.setFont(font)
        self.controlnet_dropdown.setObjectName("controlnet_dropdown")
        self.gridLayout_2.addWidget(self.controlnet_dropdown, 13, 0, 1, 1)
        self.image_scale_box = QtWidgets.QGroupBox(parent=self.scrollAreaWidgetContents_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.image_scale_box.sizePolicy().hasHeightForWidth())
        self.image_scale_box.setSizePolicy(sizePolicy)
        self.image_scale_box.setMinimumSize(QtCore.QSize(75, 60))
        self.image_scale_box.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        self.image_scale_box.setFont(font)
        self.image_scale_box.setObjectName("image_scale_box")
        self.gridLayout_9 = QtWidgets.QGridLayout(self.image_scale_box)
        self.gridLayout_9.setContentsMargins(9, 6, 6, 6)
        self.gridLayout_9.setObjectName("gridLayout_9")
        self.image_scale_slider = QtWidgets.QSlider(parent=self.image_scale_box)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.image_scale_slider.sizePolicy().hasHeightForWidth())
        self.image_scale_slider.setSizePolicy(sizePolicy)
        self.image_scale_slider.setMinimumSize(QtCore.QSize(50, 0))
        self.image_scale_slider.setMaximum(10000)
        self.image_scale_slider.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.image_scale_slider.setObjectName("image_scale_slider")
        self.gridLayout_9.addWidget(self.image_scale_slider, 0, 0, 1, 1)
        self.image_scale_spinbox = QtWidgets.QDoubleSpinBox(parent=self.image_scale_box)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Maximum, QtWidgets.QSizePolicy.Policy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.image_scale_spinbox.sizePolicy().hasHeightForWidth())
        self.image_scale_spinbox.setSizePolicy(sizePolicy)
        self.image_scale_spinbox.setMinimumSize(QtCore.QSize(75, 24))
        self.image_scale_spinbox.setMaximumSize(QtCore.QSize(75, 24))
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(False)
        self.image_scale_spinbox.setFont(font)
        self.image_scale_spinbox.setMaximum(100.0)
        self.image_scale_spinbox.setSingleStep(0.01)
        self.image_scale_spinbox.setObjectName("image_scale_spinbox")
        self.gridLayout_9.addWidget(self.image_scale_spinbox, 0, 1, 1, 1)
        self.gridLayout_2.addWidget(self.image_scale_box, 19, 0, 1, 1)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.label_4 = QtWidgets.QLabel(parent=self.scrollAreaWidgetContents_3)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        self.label_4.setFont(font)
        self.label_4.setObjectName("label_4")
        self.horizontalLayout_2.addWidget(self.label_4)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem)
        self.use_prompt_builder_checkbox = QtWidgets.QCheckBox(parent=self.scrollAreaWidgetContents_3)
        font = QtGui.QFont()
        font.setPointSize(8)
        font.setBold(True)
        self.use_prompt_builder_checkbox.setFont(font)
        self.use_prompt_builder_checkbox.setLayoutDirection(QtCore.Qt.LayoutDirection.LeftToRight)
        self.use_prompt_builder_checkbox.setObjectName("use_prompt_builder_checkbox")
        self.horizontalLayout_2.addWidget(self.use_prompt_builder_checkbox)
        self.gridLayout_2.addLayout(self.horizontalLayout_2, 1, 0, 1, 1)
        self.gridLayout_4.addLayout(self.gridLayout_2, 4, 0, 1, 1)
        self.scrollArea.setWidget(self.scrollAreaWidgetContents_3)
        self.gridLayout_7.addWidget(self.scrollArea, 0, 0, 1, 1)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.label.setText(_translate("Form", "Model"))
        self.controlnet_groupbox.setTitle(_translate("Form", "Controlnet Scale"))
        self.to_canvas_radio.setText(_translate("Form", "Single"))
        self.deterministic_radio.setText(_translate("Form", "Batch"))
        self.generate.setText(_translate("Form", "Generate"))
        self.samples_groupbox.setTitle(_translate("Form", "Samples"))
        self.interrupt_button.setText(_translate("Form", "Interrupt"))
        self.strength.setTitle(_translate("Form", "Strength"))
        self.full_image_radiobutton.setText(_translate("Form", "Full image"))
        self.active_grid_radiobutton.setText(_translate("Form", "Active grid"))
        self.downscale_label.setText(_translate("Form", "Downscale N times before upscale"))
        self.final_size_label.setText(_translate("Form", "output size"))
        self.final_size.setText(_translate("Form", "1920x1920"))
        self.groupBox_24.setTitle(_translate("Form", "Seed"))
        self.random_checkbox.setText(_translate("Form", "Random"))
        self.scheduler_label.setText(_translate("Form", "Scheduler"))
        self.groupBox_21.setTitle(_translate("Form", "Steps"))
        self.scale_box.setTitle(_translate("Form", "Scale"))
        self.label_5.setText(_translate("Form", "Negative prompt"))
        self.controlnet_label.setText(_translate("Form", "Controlnet"))
        self.enable_controlnet_checkbox.setText(_translate("Form", "Use Controlnet"))
        self.image_scale_box.setTitle(_translate("Form", "Image Scale"))
        self.label_4.setText(_translate("Form", "Prompt"))
        self.use_prompt_builder_checkbox.setText(_translate("Form", "Use Prompt Builder"))



from PyQt6.QtCore import QPointF, QRectF
from PyQt6.QtGui import QPainterPath, QPainter, QPen, QColor, QPolygonF
from PyQt6.QtWidgets import QWidget


class Balloon(QWidget):
    def __init__(self, parent=None):
        super().__init__(parent)
        self._tail_pos = QPointF(0, 0)
        self._balloon_path = QPainterPath()
        self._tail_path = QPainterPath()
        self._color = QColor(255, 255, 255)
        self._pen = QPen(QColor(0, 0, 0), 3)
        self._update_balloon_path()

    def draw(self, painter):
        painter.setRenderHint(QPainter.RenderHint.Antialiasing)
        painter.setPen(self._pen)
        painter.setBrush(self._color)
        painter.drawPath(self._balloon_path)
        painter.drawPath(self._tail_path)

    def resizeEvent(self, event):
        self._update_balloon_path()

    def set_color(self, color):
        self._color = color
        self.update()

    def set_pen(self, pen):
        self._pen = pen
        self.update()

    def set_tail_pos(self, pos):
        self._tail_pos = pos
        self._update_balloon_path()
        self.update()

    def _update_balloon_path(self):
        balloon_rect = QRectF(0, 0, self.width(), self.height() - 20)
        tail_rect = QRectF(0, 0, 20, 20)
        tail_rect.moveCenter(self._tail_pos)

        self._balloon_path = QPainterPath()
        self._balloon_path.addRoundedRect(balloon_rect, 10, 10)

        self._tail_path = QPainterPath()
        tail_points = QPolygonF()
        tail_points.append(QPointF(tail_rect.left(), tail_rect.center().y()))
        tail_points.append(QPointF(tail_rect.right(), tail_rect.top()))
        tail_points.append(QPointF(tail_rect.right(), tail_rect.bottom()))
        self._tail_path.addPolygon(tail_points)
        self._tail_path.closeSubpath()

        self.update()



# Form implementation generated from reading ui file '/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/prompt_browser.ui'
#
# Created by: PyQt6 UI code generator 6.4.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(397, 304)
        self.gridLayout_2 = QtWidgets.QGridLayout(Dialog)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.scrollArea = QtWidgets.QScrollArea(parent=Dialog)
        self.scrollArea.setWidgetResizable(True)
        self.scrollArea.setObjectName("scrollArea")
        self.scrollAreaWidgetContents = QtWidgets.QWidget()
        self.scrollAreaWidgetContents.setGeometry(QtCore.QRect(0, 0, 377, 284))
        self.scrollAreaWidgetContents.setObjectName("scrollAreaWidgetContents")
        self.scrollArea.setWidget(self.scrollAreaWidgetContents)
        self.gridLayout_2.addWidget(self.scrollArea, 0, 0, 1, 1)

        self.retranslateUi(Dialog)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Dialog"))



# Form implementation generated from reading ui file '/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/model_merger.ui'
#
# Created by: PyQt6 UI code generator 6.4.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(400, 630)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Dialog.sizePolicy().hasHeightForWidth())
        Dialog.setSizePolicy(sizePolicy)
        Dialog.setMinimumSize(QtCore.QSize(1, 630))
        self.gridLayout = QtWidgets.QGridLayout(Dialog)
        self.gridLayout.setObjectName("gridLayout")
        self.addModel_button = QtWidgets.QPushButton(parent=Dialog)
        self.addModel_button.setObjectName("addModel_button")
        self.gridLayout.addWidget(self.addModel_button, 7, 0, 1, 1)
        self.model_types = QtWidgets.QComboBox(parent=Dialog)
        self.model_types.setObjectName("model_types")
        self.gridLayout.addWidget(self.model_types, 1, 0, 1, 1)
        self.label_4 = QtWidgets.QLabel(parent=Dialog)
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_4.setFont(font)
        self.label_4.setObjectName("label_4")
        self.gridLayout.addWidget(self.label_4, 9, 0, 1, 1)
        self.label_3 = QtWidgets.QLabel(parent=Dialog)
        font = QtGui.QFont()
        font.setBold(True)
        self.label_3.setFont(font)
        self.label_3.setObjectName("label_3")
        self.gridLayout.addWidget(self.label_3, 2, 0, 1, 1)
        self.label_6 = QtWidgets.QLabel(parent=Dialog)
        font = QtGui.QFont()
        font.setBold(True)
        self.label_6.setFont(font)
        self.label_6.setObjectName("label_6")
        self.gridLayout.addWidget(self.label_6, 8, 0, 1, 1)
        self.base_models = QtWidgets.QComboBox(parent=Dialog)
        self.base_models.setObjectName("base_models")
        self.gridLayout.addWidget(self.base_models, 3, 0, 1, 1)
        self.label = QtWidgets.QLabel(parent=Dialog)
        font = QtGui.QFont()
        font.setBold(True)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 0, 0, 1, 1)
        self.models = QtWidgets.QTabWidget(parent=Dialog)
        self.models.setObjectName("models")
        self.gridLayout.addWidget(self.models, 5, 0, 1, 1)
        self.model_name = QtWidgets.QLineEdit(parent=Dialog)
        self.model_name.setObjectName("model_name")
        self.gridLayout.addWidget(self.model_name, 10, 0, 1, 1)
        self.label_5 = QtWidgets.QLabel(parent=Dialog)
        font = QtGui.QFont()
        font.setBold(True)
        self.label_5.setFont(font)
        self.label_5.setObjectName("label_5")
        self.gridLayout.addWidget(self.label_5, 4, 0, 1, 1)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.merge_button = QtWidgets.QPushButton(parent=Dialog)
        self.merge_button.setObjectName("merge_button")
        self.horizontalLayout.addWidget(self.merge_button)
        self.progressBar = QtWidgets.QProgressBar(parent=Dialog)
        self.progressBar.setProperty("value", 0)
        self.progressBar.setObjectName("progressBar")
        self.horizontalLayout.addWidget(self.progressBar)
        self.gridLayout.addLayout(self.horizontalLayout, 11, 0, 1, 1)

        self.retranslateUi(Dialog)
        self.models.setCurrentIndex(-1)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Model Merger"))
        self.addModel_button.setText(_translate("Dialog", "Add model"))
        self.label_4.setText(_translate("Dialog", "Save the merged model as this name"))
        self.label_3.setText(_translate("Dialog", "Base model"))
        self.label_6.setText(_translate("Dialog", "Model Name"))
        self.label.setText(_translate("Dialog", "Model Type"))
        self.label_5.setText(_translate("Dialog", "Models to merge into base model"))
        self.merge_button.setText(_translate("Dialog", "Merge"))



from setuptools import setup, find_packages

setup(
    name='airunner',
    version="2.0.3",
    author="Capsize LLC",
    description="A Stable Diffusion GUI",
    long_description=open("README.md", "r", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    keywords="ai, chatbot, chat, ai",
    license="AGPL-3.0",
    author_email="contact@capsize.gg",
    url="https://github.com/Capsize-Games/airunner",
    package_dir={"": "src"},
    packages=find_packages("src"),
    python_requires=">=3.10.0",
    install_requires=[
        "aihandler==1.18.1",
    ]
)



# Form implementation generated from reading ui file '/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/widgets/slider.ui'
#
# Created by: PyQt6 UI code generator 6.4.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(242, 93)
        self.gridLayout = QtWidgets.QGridLayout(Form)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setSpacing(0)
        self.gridLayout.setObjectName("gridLayout")
        self.slider = QtWidgets.QSlider(parent=Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.slider.sizePolicy().hasHeightForWidth())
        self.slider.setSizePolicy(sizePolicy)
        self.slider.setAutoFillBackground(False)
        self.slider.setMaximum(100)
        self.slider.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.slider.setObjectName("slider")
        self.gridLayout.addWidget(self.slider, 0, 0, 1, 1)
        self.spinbox = QtWidgets.QDoubleSpinBox(parent=Form)
        self.spinbox.setStyleSheet("background-color: transparent;")
        self.spinbox.setWrapping(False)
        self.spinbox.setFrame(False)
        self.spinbox.setAlignment(QtCore.Qt.AlignmentFlag.AlignCenter)
        self.spinbox.setButtonSymbols(QtWidgets.QAbstractSpinBox.ButtonSymbols.UpDownArrows)
        self.spinbox.setProperty("showGroupSeparator", False)
        self.spinbox.setMaximum(1.0)
        self.spinbox.setSingleStep(0.01)
        self.spinbox.setObjectName("spinbox")
        self.gridLayout.addWidget(self.spinbox, 0, 1, 1, 1)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))



# Form implementation generated from reading ui file '/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/widgets/layer_container_widget.ui'
#
# Created by: PyQt6 UI code generator 6.4.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(277, 318)
        self.gridLayout = QtWidgets.QGridLayout(Form)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setSpacing(0)
        self.gridLayout.setObjectName("gridLayout")
        self.layers = QtWidgets.QScrollArea(parent=Form)
        self.layers.setStyleSheet("border-radius: 0px")
        self.layers.setFrameShape(QtWidgets.QFrame.Shape.StyledPanel)
        self.layers.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.layers.setWidgetResizable(True)
        self.layers.setAlignment(QtCore.Qt.AlignmentFlag.AlignLeading|QtCore.Qt.AlignmentFlag.AlignLeft|QtCore.Qt.AlignmentFlag.AlignTop)
        self.layers.setObjectName("layers")
        self.scrollAreaWidgetContents = QtWidgets.QWidget()
        self.scrollAreaWidgetContents.setGeometry(QtCore.QRect(0, 0, 277, 278))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.scrollAreaWidgetContents.sizePolicy().hasHeightForWidth())
        self.scrollAreaWidgetContents.setSizePolicy(sizePolicy)
        self.scrollAreaWidgetContents.setObjectName("scrollAreaWidgetContents")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.scrollAreaWidgetContents)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setSpacing(0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.layers.setWidget(self.scrollAreaWidgetContents)
        self.gridLayout.addWidget(self.layers, 0, 0, 1, 1)
        self.horizontalWidget = QtWidgets.QWidget(parent=Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.horizontalWidget.sizePolicy().hasHeightForWidth())
        self.horizontalWidget.setSizePolicy(sizePolicy)
        self.horizontalWidget.setLayoutDirection(QtCore.Qt.LayoutDirection.LeftToRight)
        self.horizontalWidget.setObjectName("horizontalWidget")
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout(self.horizontalWidget)
        self.horizontalLayout_8.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_8.setSpacing(0)
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.new_layer_button = QtWidgets.QPushButton(parent=self.horizontalWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Fixed, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.new_layer_button.sizePolicy().hasHeightForWidth())
        self.new_layer_button.setSizePolicy(sizePolicy)
        self.new_layer_button.setMinimumSize(QtCore.QSize(40, 40))
        self.new_layer_button.setStyleSheet("border-color: rgb(61, 56, 70);")
        self.new_layer_button.setText("")
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap("/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/widgets/../../src/icons/035-new.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
        self.new_layer_button.setIcon(icon)
        self.new_layer_button.setIconSize(QtCore.QSize(24, 24))
        self.new_layer_button.setFlat(True)
        self.new_layer_button.setObjectName("new_layer_button")
        self.horizontalLayout_8.addWidget(self.new_layer_button)
        self.layer_up_button = QtWidgets.QPushButton(parent=self.horizontalWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.layer_up_button.sizePolicy().hasHeightForWidth())
        self.layer_up_button.setSizePolicy(sizePolicy)
        self.layer_up_button.setMinimumSize(QtCore.QSize(40, 40))
        self.layer_up_button.setStyleSheet("border-color: rgb(61, 56, 70);")
        self.layer_up_button.setText("")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap("/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/widgets/../../src/icons/041-up-arrow.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
        self.layer_up_button.setIcon(icon1)
        self.layer_up_button.setIconSize(QtCore.QSize(24, 24))
        self.layer_up_button.setFlat(True)
        self.layer_up_button.setObjectName("layer_up_button")
        self.horizontalLayout_8.addWidget(self.layer_up_button)
        self.layer_down_button = QtWidgets.QPushButton(parent=self.horizontalWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.layer_down_button.sizePolicy().hasHeightForWidth())
        self.layer_down_button.setSizePolicy(sizePolicy)
        self.layer_down_button.setMinimumSize(QtCore.QSize(40, 40))
        self.layer_down_button.setStyleSheet("border-color: rgb(61, 56, 70);")
        self.layer_down_button.setText("")
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap("/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/widgets/../../src/icons/042-down-arrow.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
        self.layer_down_button.setIcon(icon2)
        self.layer_down_button.setIconSize(QtCore.QSize(24, 24))
        self.layer_down_button.setFlat(True)
        self.layer_down_button.setObjectName("layer_down_button")
        self.horizontalLayout_8.addWidget(self.layer_down_button)
        spacerItem = QtWidgets.QSpacerItem(500, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout_8.addItem(spacerItem)
        self.delete_layer_button = QtWidgets.QPushButton(parent=self.horizontalWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Fixed, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.delete_layer_button.sizePolicy().hasHeightForWidth())
        self.delete_layer_button.setSizePolicy(sizePolicy)
        self.delete_layer_button.setMinimumSize(QtCore.QSize(40, 40))
        self.delete_layer_button.setStyleSheet("border-color: rgb(61, 56, 70);")
        self.delete_layer_button.setText("")
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap("/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/widgets/../../src/icons/006-trash.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
        self.delete_layer_button.setIcon(icon3)
        self.delete_layer_button.setIconSize(QtCore.QSize(24, 24))
        self.delete_layer_button.setFlat(True)
        self.delete_layer_button.setObjectName("delete_layer_button")
        self.horizontalLayout_8.addWidget(self.delete_layer_button)
        self.gridLayout.addWidget(self.horizontalWidget, 1, 0, 1, 1)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.new_layer_button.setToolTip(_translate("Form", "Create a new layer"))
